@@ -7,7 +7,7 @@ use Mojo::JSON;
 use Mojo::Util;
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '2.23';
+our $VERSION = '3.24';
 my $X_RE = qr{^x-};
 
 has route     => sub {undef};
@@ -58,7 +58,7 @@ sub register {
   for my $plugin (@{$config->{plugins} || [qw(+Cors +SpecRenderer +Security)]}) {
     $plugin = "Mojolicious::Plugin::OpenAPI::$plugin" if $plugin =~ s!^\+!!;
     eval "require $plugin;1" or Carp::confess("require $plugin: $@");
-    push @plugins, $plugin->new->register($app, $self, $config);
+    push @plugins, $plugin->new->register($app, {%$config, openapi => $self});
   }
 
   $self->_add_routes($app, $config);
